==> mx-packageinstaller-pkglist_19.05.12.tar.xz: mx-packageinstaller-pkglist/clonezilla.pm <==
<?xml version="1.0"?>
<app>

<category>
Utility
</category>

<name>
clonezilla
</name>

<description>
   <am>clone and restore disks and partitions</am>
   <ar>clone and restore disks and partitions</ar>
   <bg>clone and restore disks and partitions</bg>
   <ca>Clona i restaura discos i particions</ca>
   <cs>clone and restore disks and partitions</cs>
   <da>klon og gendan diske og partitioner</da>
   <de>Laufwerke und Partitonen klonen und wieder herstellen.</de>
   <el>να κλωνοποιήσετε και να επαναφέρετε δίσκους και διαμερίσματα</el>
   <en>clone and restore disks and partitions</en>
   <es>Clona y restaura discos y particiones</es>
   <et>clone and restore disks and partitions</et>
   <eu>clone and restore disks and partitions</eu>
   <fa>clone and restore disks and partitions</fa>
   <fi>kloonaa ja palauta levyjä ja osioita</fi>
   <fr>Copie et restauration de disques et de partitions</fr>
   <he_IL>clone and restore disks and partitions</he_IL>
   <hi>clone and restore disks and partitions</hi>
   <hr>clone and restore disks and partitions</hr>
   <hu>clone and restore disks and partitions</hu>
   <id>clone and restore disks and partitions</id>
   <is>clone and restore disks and partitions</is>
   <it>clona e ripristina dischi e partizioni</it>
   <ja_JP>clone and restore disks and partitions</ja_JP>
   <ja>clone and restore disks and partitions</ja>
   <kk>clone and restore disks and partitions</kk>
   <ko>clone and restore disks and partitions</ko>
   <lt>clone and restore disks and partitions</lt>
   <mk>clone and restore disks and partitions</mk>
   <nb>clone and restore disks and partitions</nb>
   <nl>kloon en herstel schijven en partities</nl>
   <pl>klonowanie i przywracanie dysków i partycji</pl>
   <pt_BR>restaurar ou fazer uma cópia de discos e partições</pt_BR>
   <pt>clonar e restaurar discos e partições</pt>
   <ro>clone and restore disks and partitions</ro>
   <ru>Клонирование и восстановление дисков и разделов</ru>
   <sk>clone and restore disks and partitions</sk>
   <sl>clone and restore disks and partitions</sl>
   <sq>clone and restore disks and partitions</sq>
   <sr>clone and restore disks and partitions</sr>
   <sv>klona och återställ diskar och partitioner</sv>
   <tr>clone and restore disks and partitions</tr>
   <uk>клонування та відновлення дисків і розділів</uk>
   <zh_CN>clone and restore disks and partitions</zh_CN>
   <zh_TW>clone and restore disks and partitions</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
clonezilla
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
clonezilla
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/clonezilla.pm <==
<?xml version="1.0"?>
<app>

<category>
Utility
</category>

<name>
clonezilla
</name>

<description>
   <am>clone and restore disks and partitions</am>
   <ar>clone and restore disks and partitions</ar>
   <bg>clone and restore disks and partitions</bg>
   <ca>Clona i restaura discos i particions</ca>
   <cs>clone and restore disks and partitions</cs>
   <da>klon og gendan diske og partitioner</da>
   <de>Laufwerke und Partitonen klonen und wieder herstellen.</de>
   <el>να κλωνοποιήσετε και να επαναφέρετε δίσκους και διαμερίσματα</el>
   <en>clone and restore disks and partitions</en>
   <es>Clona y restaura discos y particiones</es>
   <et>clone and restore disks and partitions</et>
   <eu>clone and restore disks and partitions</eu>
   <fa>clone and restore disks and partitions</fa>
   <fi>kloonaa ja palauta levyjä ja osioita</fi>
   <fr>Copie et restauration de disques et de partitions</fr>
   <he_IL>clone and restore disks and partitions</he_IL>
   <hi>clone and restore disks and partitions</hi>
   <hr>clone and restore disks and partitions</hr>
   <hu>clone and restore disks and partitions</hu>
   <id>clone and restore disks and partitions</id>
   <is>clone and restore disks and partitions</is>
   <it>clona e ripristina dischi e partizioni</it>
   <ja_JP>clone and restore disks and partitions</ja_JP>
   <ja>clone and restore disks and partitions</ja>
   <kk>clone and restore disks and partitions</kk>
   <ko>clone and restore disks and partitions</ko>
   <lt>clone and restore disks and partitions</lt>
   <mk>clone and restore disks and partitions</mk>
   <nb>clone and restore disks and partitions</nb>
   <nl>kloon en herstel schijven en partities</nl>
   <pl>klonowanie i przywracanie dysków i partycji</pl>
   <pt_BR>restaurar ou fazer uma cópia de discos e partições</pt_BR>
   <pt>Clonar e restaurar discos e partições</pt>
   <ro>clone and restore disks and partitions</ro>
   <ru>Клонирование и восстановление дисков и разделов</ru>
   <sk>clone and restore disks and partitions</sk>
   <sl>kloniranje in obnova diskov in razdelkov</sl>
   <sq>clone and restore disks and partitions</sq>
   <sr>clone and restore disks and partitions</sr>
   <sv>klona och återställ diskar och partitioner</sv>
   <tr>clone and restore disks and partitions</tr>
   <uk>клонування та відновлення дисків і розділів</uk>
   <zh_CN>clone and restore disks and partitions</zh_CN>
   <zh_TW>clone and restore disks and partitions</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
clonezilla
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
clonezilla
</uninstall_package_names>
</app>
